### 404

[Not found](https://github.com/AlexanderDokuchaev/FAILED)
[Not exist](https://not_exist_github.githubcom/)

### Incorrect path

[1](/test/fail.md1)
[1](fail.md1)

### Incorrect fragment

[1](/tests/test_md_files/fail.md#fail)

[1](not_exist_dir)

[1](error://urls/)

[1](https://example.com/(bracket))

[1](https://example.com]https://example.com)
